%{!?_python_sitelib: %global _python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}

Summary:   Provides configuration and customization of cloud instance.
Name:      cloud-init
Version: 0.5.15
Release: 20%{?dist}
License:   GPLv3
Group:     System Environment/Base
URL:       https://launchpad.net/ubuntu/+archive/primary/+files/cloud-init_%{version}.orig.tar.gz
Source0:   cloud-init-%{version}.tar.gz
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

# Common user setup requirement:
Requires: sudo

# Repo setup requirements:
Requires: rpm
Requires: yum

BuildRequires: python-devel
Requires:      python-configobj
Requires:      python-cheetah
Requires:      python-yaml

Provides: cloud-init(genrepo)

%global cloud_user        ec2-user
%global cloud_user_id     222
%global cloud_user_groups wheel
%global cloud_dir         /var/lib/cloud
%global cloud_data_dir    %{cloud_dir}/data
%global cloud_config_dir  /etc/cloud

%description
Basic AMI configuration in cloud environments.

%prep
%setup -q

%build
# Remove non-amazon linux templates
%__rm templates/sources.list.tmpl

# Remove unnecessary handlers (unsupported) 
%__rm cloudinit/CloudConfig/cc_apt_update_upgrade.py
%__rm cloudinit/CloudConfig/cc_byobu.py
%__rm cloudinit/CloudConfig/cc_puppet.py
%__rm cloudinit/CloudConfig/cc_ssh_import_id.py
%__rm cloudinit/CloudConfig/cc_updates_check.py

%{__python} setup.py build

%install
[ ${RPM_BUILD_ROOT} != "/" ] && %__rm -rf ${RPM_BUILD_ROOT}

%{__python} setup.py install --root=%{buildroot}

# Drop a blank cloud config into expected location
%__mkdir_p %{buildroot}/%{cloud_data_dir}
/bin/touch %{buildroot}/%{cloud_data_dir}/cloud-config.txt

# Strip file extensions:
for script in %{buildroot}/usr/bin/*.py; do
   [ -f "$script" ] && mv "$script" "${script%.py}"
done

rm -rf $RPM_BUILD_ROOT/%{_docdir}/%{name}

# remove stuff we don't need
rm -rf $RPM_BUILD_ROOT/usr/lib/%{name}

%post
# Add ec2-user
grep "^%{cloud_user}:" /etc/passwd &> /dev/null
if [ $? != 0 ]; then
    useradd -m -u %{cloud_user_id} -G %{cloud_user_groups} -c "EC2 Default User" %{cloud_user}
fi

# Add ec2-user to /etc/sudoers
if [ -e /etc/sudoers ]; then
    %{__cp}  -fa /etc/sudoers /etc/sudoers-
    %{__sed} -i  's/^%{cloud_user}.*//g' /etc/sudoers-
    echo "%{cloud_user} ALL = NOPASSWD: ALL" >> /etc/sudoers-
    %{__mv} /etc/sudoers- /etc/sudoers
else
    echo "%{cloud_user} ALL = NOPASSWD: ALL" >> /etc/sudoers
    chmod 440 /etc/sudoers
fi

/sbin/chkconfig --add %{name}
/sbin/chkconfig --add %{name}-user-scripts
/sbin/chkconfig %{name} on
/sbin/chkconfig %{name}-user-scripts on

%preun
if [ "$1" = "0" ]; then
    /sbin/chkconfig %{name} off
    /sbin/chkconfig %{name}-user-scripts off
    /sbin/chkconfig --del %{name}
    /sbin/chkconfig --del %{name}-user-scripts
fi

%postun
if [ "$1" = "0" ]; then
    if [ -d "%{cloud_dir}" ]; then 
        if [ ! "$(ls -A %{cloud_dir})" ]; then
            rmdir %{cloud_dir}
        fi
    fi
fi

%clean
[ ${RPM_BUILD_ROOT} != "/" ] && %__rm -rf ${RPM_BUILD_ROOT}

%files
%defattr(0644,root,root,0755)
%doc doc/* tools/write-mime-multipart

%attr(0755,root,root) %dir /etc/cloud
%attr(0755,root,root) %dir /etc/cloud/templates

%attr(0755,root,root) /etc/rc.d/init.d/%{name}
%attr(0755,root,root) /etc/rc.d/init.d/%{name}-user-scripts
%config /etc/sysconfig/cloudinit

%config /etc/cloud/cloud.cfg
%config /etc/cloud/dist-defs.cfg

/etc/cloud/templates/default-locale.tmpl
/etc/cloud/templates/hosts.tmpl
# moved to system-release rpm
#/etc/cloud/templates/*.repo.tmpl

%attr(0600,root,root) %config %{cloud_data_dir}/cloud-config.txt

%attr(0755,root,root) /usr/bin/cloud-init-cfg
%attr(0755,root,root) /usr/bin/cloud-init-run-module
%attr(0755,root,root) /usr/bin/cloud-init
%attr(0755,root,root) /usr/bin/write-mime-multipart

%{_python_sitelib}/*

%changelog
* Tue Nov 29 2011 Sam Bashon <sam@bashton.com>
- Rebuild for EL6

* Wed Oct 26 2011 Cristian Gafton <gafton@amazon.com>
- add support for limiting security updates applied by severity level

* Wed Oct 26 2011 Cristian Gafton <gafton@amazon.com>
- restore file permissions when updating yum.conf

* Tue Oct 25 2011 Cristian Gafton <gafton@amazon.com>
- add targets: ami-devel and ami-updates

* Tue Oct 25 2011 Cristian Gafton <gafton@amazon.com>
- add support for locking the yum repos releasever to a particular version

* Wed Sep 21 2011 Cristian Gafton <gafton@amazon.com>
- typos fixes and code formating update (noops)

* Wed Sep 21 2011 Cristian Gafton <gafton@amazon.com>
- Add support for gpgcheck=0 config parameter in repository definitions

* Wed Sep 21 2011 Cristian Gafton <gafton@amazon.com>
- fix typo that resulted in misreporting configuration errors when new repos are defined in cloud config

* Thu Aug 25 2011 Cristian Gafton <gafton@amazon.com>
- remove superfluous changelog timestamp that rpm doesn't parse nor understands

* Thu Aug 25 2011 Cristian Gafton <gafton@amazon.com>
- fail more gracefully when cloud dataservice is not available

* Thu Aug 25 2011 Cristian Gafton <gafton@amazon.com>
- fix for python macro definition in spec file

* Thu Aug 25 2011 Cristian Gafton <gafton@amazon.com>
- add support for "cloud-init-cfg genrepo" for simple yum repo regeneration

* Thu Aug 25 2011 Cristian Gafton <gafton@amazon.com>
- fix build path URL

* Mon Jul 18 2011 Nathan Blackham <blackham@amazon.com>
- update Makefile for add-pkg

* Mon Jul 18 2011 Nathan Blackham <blackham@amazon.com>
- Fix bug with boot-hook code.

* Wed Mar 9 2011 Cristian Gafton <gafton@amazon.com>
- udpate gitignore patterns

* Wed Mar 9 2011 Cristian Gafton <gafton@amazon.com>
- add documentation ofr repo_upgrade

* Mon Feb 21 2011 Cristian Gafton <gafton@amazon.com>
- do not output invalid fstab lines for missing devices.

* Wed Feb 9 2011 Nathan Blackham <blackham@amazon.com>
- log cloud init user scripts to a logfile

* Fri Jan 28 2011 Cristian Gafton <gafton@amazon.com>
- render all template repo files by the name $name*.repo.tmp instead of just $name.repo.tmpl

* Thu Jan 27 2011 Cristian Gafton <gafton@amazon.com>
- make koji builds work for cases when the build tags and target tag is not the same

* Mon Jan 24 2011 Nathan Blackham <blackham@amazon.com>
- remove version from dist-defs.cfg

* Mon Jan 24 2011 Nathan Blackham <blackham@amazon.com>
- removing amzn repo template files -> moved to system-release rpm

* Fri Dec 17 2010 Cristian Gafton <gafton@amazon.com>
- undo erroneous extra argument for package_setup

* Tue Nov 30 2010 Nathan Blackham <blackham@amazon.com>
- update template file to current repository state

* Thu Nov 18 2010 Cristian Gafton <gafton@amazon.com>
- log cloud init startup to a logfile

* Thu Nov 18 2010 Cristian Gafton <gafton@amazon.com>
- allow scratch builds for koji

* Thu Nov 18 2010 Cristian Gafton <gafton@amazon.com>
- add support for applying security updates on first launch

* Mon Nov 15 2010 Nathan Blackham <blackham@amazon.com>
- change repo directory structure

* Mon Nov 15 2010 Nathan Blackham <blackham@amazon.com>
- add start-local to init script

* Thu Nov 4 2010 Nathan Blackham <blackham@amazon.com>
- update build target

* Thu Nov 4 2010 Nathan Blackham <blackham@amazon.com>
- only check for cache in EC2 DataSource

* Mon Nov 1 2010 Cristian Gafton <gafton@amazon.com>
- pull changelog from global project history

* Fri Oct 8 2010 Nathan Blackham <blackham@amazon.com>
- Fix cache issue when rebundling AL#970

* Tue Sep 14 2010 Nathan Blackham <blackham@amazon.com>
- rewording log messages about swap, when it isn't present on the system

* Tue Sep 14 2010 Nathan Blackham <blackham@amazon.com>
- removing nobootwait option in cloud.cfg as it is not available in current version of util-linux

* Mon Sep 13 2010 Cristian Gafton <gafton@amazon.com>
- update default config to work with t1.micro if ephemeral0 is not present.

* Mon Sep 13 2010 Cristian Gafton <gafton@amazon.com>
- Merge branch 'upstream'

* Mon Sep 13 2010 Cristian Gafton <gafton@amazon.com>
- Import upstream trunk

* Sun Sep 12 2010 Nathan Blackham <blackham@amazon.com>
- modifying init script to used new syntax of cloud-init

* Tue Sep 7 2010 Nathan Blackham <blackham@amazon.com>
- fix typo in add yum repo section

* Fri Sep 3 2010 Cristian Gafton <gafton@amazon.com>
- simplify spec file

* Fri Sep 3 2010 Cristian Gafton <gafton@amazon.com>
- add support to build from origin/master instead of commit id

* Fri Sep 3 2010 Cristian Gafton <gafton@amazon.com>
- Merge branch 'master' of ssh://kaos-source.amazon.com/opt/git/distro/Amazon/cloud-init

* Fri Sep 3 2010 Cristian Gafton <gafton@amazon.com>
- fix initial spec file to match current version being built

* Fri Sep 3 2010 Cristian Gafton <gafton@amazon.com>
- Merge commit 'upstream/0.5.14' Resolved Conflicts:         cloud-init.py         cloudinit/DataSourceEc2.py

* Fri Sep 3 2010 Cristian Gafton <gafton@amazon.com>
- Merge commit 'upstream/0.5.13' resolved conflicts:         cloud-init.py         cloud.cfg         cloudinit/CloudConfig/__init__.py

* Fri Sep 3 2010 Cristian Gafton <gafton@amazon.com>
- Import upstream trunk

* Fri Sep 3 2010 Cristian Gafton <gafton@amazon.com>
- Import upstream tag 0.5.14

* Fri Sep 3 2010 Cristian Gafton <gafton@amazon.com>
- Import upstream tag 0.5.13

* Fri Sep 3 2010 Cristian Gafton <gafton@amazon.com>
- add script to help in pulling upstream sources

* Fri Sep 3 2010 Cristian Gafton <gafton@amazon.com>
- adding swap and ephermal0 mounts by default. Patch from blackham

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- extract and use the correct SHA1 for koji builds

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- add rule for add-pkg

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- Update vendor setting

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- again, fix koji build rule

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- fix koji build rule

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- update for building into the new repository

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- apply patch cloud-init-0.5.12_py26compat.patch

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- apply patch cloud-init-0.5.12_amzn_dist.patch

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- apply patch cloud-init-0.5.12_sysv.patch

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- apply patch cloud-init-0.5.12_portability.patch

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- add spec file

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- Merge branch 'upstream'

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- add Makefile

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- start from cloud-init-0.5.12

* Fri Aug 20 2010 Cristian Gafton <gafton@amazon.com>
- start repository Amazon / cloud-init
